@@ -12,8 +12,8 @@ test_that("textProjection MEAN and PCA produces a tibble with character variable
   df_for_plotting1 <- text::textProjection(
     words = Language_based_assessment_data_8$harmonywords[1:10],
     word_embeddings = word_embeddings_4$texts$harmonywords[1:10, ],
-    word_embeddings_4$word_types,
-    Language_based_assessment_data_8$hilstotal[1:10],
+    word_types_embeddings = word_embeddings_4$word_types,
+    x = Language_based_assessment_data_8$hilstotal[1:10],
     split = "mean",
     Npermutations = 2,
     n_per_split = 1,
@@ -23,7 +23,8 @@ test_that("textProjection MEAN and PCA produces a tibble with character variable
   testthat::expect_true(tibble::is_tibble(df_for_plotting1[[2]]))
   testthat::expect_is(df_for_plotting1[[2]]$words[1], "character")
   testthat::expect_is(df_for_plotting1[[2]]$n[1], "numeric")
-  testthat::expect_equal(df_for_plotting1[[2]]$dot.x[1], -3.847934, tolerance = 0.001)
+#  testthat::expect_equal(df_for_plotting1[[2]]$dot.x[1], -3.847934, tolerance = 0.001) #Not anchoring the G1 and G2 ambeddings
+  testthat::expect_equal(df_for_plotting1[[2]]$dot.x[1], -4.215651, tolerance = 0.001)
 
 
   # Pre-processing data for plotting
@@ -41,7 +42,8 @@ test_that("textProjection MEAN and PCA produces a tibble with character variable
   testthat::expect_true(tibble::is_tibble(df_for_plotting1_no_split[[2]]))
   testthat::expect_is(df_for_plotting1_no_split[[2]]$words[1], "character")
   testthat::expect_is(df_for_plotting1_no_split[[2]]$n[1], "numeric")
-  testthat::expect_equal(df_for_plotting1_no_split[[2]]$dot.x[1], -1.537714, tolerance = 0.001)
+ # testthat::expect_equal(df_for_plotting1_no_split[[2]]$dot.x[1], -1.537714, tolerance = 0.001) #Not anchoring the G1 and G2 ambeddings
+  testthat::expect_equal(df_for_plotting1_no_split[[2]]$dot.x[1],  -1.039681, tolerance = 0.001)
 
 })
 
@@ -98,6 +100,7 @@ test_that("textProjectionPlot 1-DIMENSIONS produces a plot", {
 
   expect_true(ggplot2::is.ggplot(p1$final_plot))
   expect_equal(p1$processed_word_data$dot.y[1], 2.988819, tolerance = 0.00001)
+
 })
 
 
@@ -157,6 +160,66 @@ test_that("textProjectionPlot 2-DIMENSIONS produces a plot", {
 
   expect_true(ggplot2::is.ggplot(p3$final_plot))
   expect_equal(p3$processed_word_data$x_plotted[2], 0.7323493, tolerance = 0.0001)
+
+  # Dot Product Projection Plot
+  p3 <- text::textPlot(
+    word_data = DP_projections_HILS_SWLS_100,
+    k_n_words_to_test = FALSE,
+    min_freq_words_test = 1,
+    plot_n_words_square = 0,
+    plot_n_words_p = 0,
+    plot_n_word_extreme = 0,
+    plot_n_word_extreme_xy = 5,
+    plot_n_word_frequency = 0,
+    plot_n_words_middle = 0,
+    plot_n_word_random = 0,
+    # x_axes = TRUE,
+    y_axes = TRUE,
+    p_alpha = 0.05,
+    title_top = " Dot Product Projection (DPP)",
+    x_axes_label = "Low vs. High HILS score",
+    y_axes_label = "Low vs. High SWLS score",
+    p_adjust_method = "fdr",
+    scale_y_axes_lim = NULL
+  )
+  p3
+  expect_true(ggplot2::is.ggplot(p3$final_plot))
+  expect_equal(p3$processed_word_data$x_plotted[2], 0.7323493, tolerance = 0.0001)
+
+
+  # Cohens_d pipeline
+  # Pre-processing data for plotting
+  df_cohensD <- text::textProjection(
+    words = Language_based_assessment_data_8$harmonywords,
+    word_embeddings = word_embeddings_4$texts$harmonywords,
+    word_types_embeddings = word_embeddings_4$word_types,
+    Language_based_assessment_data_8$hilstotal,
+    Language_based_assessment_data_8$swlstotal,
+    split = "quartile",
+    Npermutations = 1000,
+    n_per_split = 3
+  )
+
+  p_cohensD <- text::textPlot(
+    word_data = df_cohensD,
+    min_freq_words_test = 1,
+    plot_n_words_square = 3,
+    plot_n_words_p = 3,
+    plot_n_word_extreme = 1,
+    plot_n_word_frequency = 1,
+    plot_n_words_middle = 1,
+    projection_metric = "cohens_d",
+    y_axes = F,
+    p_alpha = 0.0005,
+    title_top = "Cohen's D Dot Product Projection (DPP)",
+    x_axes_label = "Low vs. High HILS score",
+    y_axes_label = "Low vs. High SWLS score",
+   # p_adjust_method = "fdr",
+    scale_y_axes_lim = NULL
+  )
+  p_cohensD
+  expect_true(ggplot2::is.ggplot(p_cohensD$final_plot))
+
 })
 
 
